CREATE = 'CREATE'
APPEND = 'APPEND'
OPEN = 'OPEN'
MKDIRS = 'MKDIRS'
RENAME = 'RENAME'
DELETE = 'DELETE'
GETFILESTATUS = 'GETFILESTATUS'
LISTSTATUS = 'LISTSTATUS'
GETFILECHECKSUM = 'GETFILECHECKSUM'
GETCONTENTSUMMARY = 'GETCONTENTSUMMARY'
GETXATTRS = 'GETXATTRS'
LISTXATTRS = 'LISTXATTRS'
REMOVEXATTR = 'REMOVEXATTR'
SETXATTR = 'SETXATTR'
